#line 2 "src/ppParse_flex.c"

#line 4 "src/ppParse_flex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer ppParse_flex_create_buffer
#define yy_delete_buffer ppParse_flex_delete_buffer
#define yy_flex_debug ppParse_flex_flex_debug
#define yy_init_buffer ppParse_flex_init_buffer
#define yy_flush_buffer ppParse_flex_flush_buffer
#define yy_load_buffer_state ppParse_flex_load_buffer_state
#define yy_switch_to_buffer ppParse_flex_switch_to_buffer
#define yyin ppParse_flexin
#define yyleng ppParse_flexleng
#define yylex ppParse_flexlex
#define yylineno ppParse_flexlineno
#define yyout ppParse_flexout
#define yyrestart ppParse_flexrestart
#define yytext ppParse_flextext
#define yywrap ppParse_flexwrap
#define yyalloc ppParse_flexalloc
#define yyrealloc ppParse_flexrealloc
#define yyfree ppParse_flexfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE ppParse_flexrestart(ppParse_flexin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int ppParse_flexleng;

extern FILE *ppParse_flexin, *ppParse_flexout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE ppParse_flexlex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-ppParse_flexlineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < ppParse_flexleng; ++yyl )\
                    if ( ppParse_flextext[yyl] == '\n' )\
                        --ppParse_flexlineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up ppParse_flextext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up ppParse_flextext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via ppParse_flexrestart()), so that the user can continue scanning by
	 * just pointing ppParse_flexin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when ppParse_flextext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int ppParse_flexleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow ppParse_flexwrap()'s to do buffer switches
 * instead of setting up a fresh ppParse_flexin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void ppParse_flexrestart (FILE *input_file  );
void ppParse_flex_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE ppParse_flex_create_buffer (FILE *file,int size  );
void ppParse_flex_delete_buffer (YY_BUFFER_STATE b  );
void ppParse_flex_flush_buffer (YY_BUFFER_STATE b  );
void ppParse_flexpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void ppParse_flexpop_buffer_state (void );

static void ppParse_flexensure_buffer_stack (void );
static void ppParse_flex_load_buffer_state (void );
static void ppParse_flex_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER ppParse_flex_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE ppParse_flex_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE ppParse_flex_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE ppParse_flex_scan_bytes (yyconst char *bytes,int len  );

void *ppParse_flexalloc (yy_size_t  );
void *ppParse_flexrealloc (void *,yy_size_t  );
void ppParse_flexfree (void *  );

#define yy_new_buffer ppParse_flex_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        ppParse_flexensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            ppParse_flex_create_buffer(ppParse_flexin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        ppParse_flexensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            ppParse_flex_create_buffer(ppParse_flexin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *ppParse_flexin = (FILE *) 0, *ppParse_flexout = (FILE *) 0;

typedef int yy_state_type;

extern int ppParse_flexlineno;

int ppParse_flexlineno = 1;

extern char *ppParse_flextext;
#define yytext_ptr ppParse_flextext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up ppParse_flextext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	ppParse_flexleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 20
#define YY_END_OF_BUFFER 21
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[135] =
    {   0,
        0,    0,   21,   19,   18,   18,   17,   19,   10,   16,
       15,   15,   13,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   10,   10,   10,    0,   15,   15,   14,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
        0,   10,    0,   10,    1,   15,   11,   15,   15,   15,
       15,   15,   12,   15,    0,   10,    0,   15,   15,   15,
       15,   15,   15,   15,    0,   10,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,    7,   15,    8,   15,   15,   15,

        5,   15,   15,   15,    6,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,    4,   15,   15,
       15,   15,   15,   15,    3,   15,   15,   15,   15,   15,
       15,    9,    2,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    1,    1,    1,    1,    5,
        5,    5,    6,    5,    6,    7,    5,    8,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    1,    9,    1,
        5,    1,    1,    1,   10,   10,   10,   11,   12,   10,
       10,   10,   13,   10,   10,   10,   10,   14,   10,   15,
       10,   10,   16,   10,   10,   10,   10,   10,   10,   10,
       17,    1,   17,    5,   18,    1,   19,   20,   21,   22,

       23,   24,   25,   26,   27,   10,   10,   28,   29,   30,
       31,   32,   10,   33,   34,   35,   36,   37,   38,   39,
       10,   10,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[40] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    2,    1,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2
    } ;

static yyconst flex_int16_t yy_base[136] =
    {   0,
        0,    0,  170,  171,  171,  171,  171,  161,   33,  171,
        0,  154,    0,  140,  135,  142,  125,  127,  131,   23,
      134,  141,  140,   35,   36,   43,   54,    0,  147,    0,
       19,  133,  124,  125,  125,   28,  115,  122,  121,  117,
       59,   56,  141,  140,    0,  113,    0,  119,  124,  126,
      124,  116,    0,  114,  132,  131,   63,  103,  107,  101,
       98,  105,   96,  113,  123,  122,  110,  105,  100,  107,
      102,  105,  103,   92,   99,   89,   86,   83,   84,   88,
       80,   98,   83,   85,   88,   83,   86,  104,   71,  102,
       86,   71,   84,   66,  171,   82,  171,   81,   96,   79,

      171,   73,   73,   68,  171,   67,   61,   57,   69,   68,
       59,   59,   70,   83,   50,   64,   58,  171,   50,   46,
       47,   74,   50,   45,  171,   44,   38,   43,   40,   53,
       48,  171,  171,  171,   44
    } ;

static yyconst flex_int16_t yy_def[136] =
    {   0,
      134,    1,  134,  134,  134,  134,  134,  134,  134,  134,
      135,  135,  135,  135,  135,  135,  135,  135,  135,  135,
      135,  135,  135,  134,  134,  134,  134,  135,  135,  135,
      135,  135,  135,  135,  135,  135,  135,  135,  135,  135,
      134,  134,  134,  134,  135,  135,  135,  135,  135,  135,
      135,  135,  135,  135,  134,  134,  134,  135,  135,  135,
      135,  135,  135,  135,  134,  134,  135,  135,  135,  135,
      135,  135,  135,  135,  135,  135,  135,  135,  135,  135,
      135,  135,  135,  135,  135,  135,  135,  135,  135,  135,
      135,  135,  135,  135,  134,  135,  134,  135,  135,  135,

      134,  135,  135,  135,  134,  135,  135,  135,  135,  135,
      135,  135,  135,  135,  135,  135,  135,  134,  135,  135,
      135,  135,  135,  135,  134,  135,  135,  135,  135,  135,
      135,  134,  134,    0,  134
    } ;

static yyconst flex_int16_t yy_nxt[211] =
    {   0,
        4,    5,    6,    5,    7,    7,    8,    9,   10,   11,
       11,   12,   13,   11,   14,   11,    4,    4,   11,   11,
       15,   16,   17,   18,   11,   19,   11,   11,   11,   11,
       11,   20,   11,   21,   22,   11,   23,   11,   11,   25,
       26,   36,   24,   42,   27,   28,   41,   27,   46,   25,
       26,  133,   47,   37,   27,   27,  132,   41,   27,   43,
       51,   44,   52,   42,   55,   27,   56,   57,   65,  101,
       66,  131,  130,  129,  128,  127,  126,  125,   57,  124,
      123,  122,  121,  102,  120,  119,  118,  117,  116,  115,
      114,  113,  112,  111,  110,  109,  108,  107,  106,  105,

      104,  103,  100,   99,   98,   97,   96,   95,   94,   93,
       92,   91,   90,   89,   88,   87,   86,   85,   84,   83,
       82,   81,   80,   79,   78,   77,   76,   75,   74,   66,
       66,   73,   72,   71,   70,   69,   68,   67,   56,   56,
       64,   63,   62,   61,   60,   59,   58,   44,   44,   54,
       47,   47,   53,   50,   49,   47,   48,   45,   40,   39,
       38,   35,   34,   33,   32,   31,   30,   29,   24,  134,
        3,  134,  134,  134,  134,  134,  134,  134,  134,  134,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,

      134,  134,  134,  134,  134,  134,  134,  134,  134,  134
    } ;

static yyconst flex_int16_t yy_chk[211] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    9,
        9,   20,   24,   25,    9,  135,   24,   25,   31,   26,
       26,  131,   31,   20,   26,    9,  130,   24,   25,   27,
       36,   27,   36,   42,   41,   26,   41,   42,   57,   94,
       57,  129,  128,  127,  126,  124,  123,  122,   42,  121,
      120,  119,  117,   94,  116,  115,  114,  113,  112,  111,
      110,  109,  108,  107,  106,  104,  103,  102,  100,   99,

       98,   96,   93,   92,   91,   90,   89,   88,   87,   86,
       85,   84,   83,   82,   81,   80,   79,   78,   77,   76,
       75,   74,   73,   72,   71,   70,   69,   68,   67,   66,
       65,   64,   63,   62,   61,   60,   59,   58,   56,   55,
       54,   52,   51,   50,   49,   48,   46,   44,   43,   40,
       39,   38,   37,   35,   34,   33,   32,   29,   23,   22,
       21,   19,   18,   17,   16,   15,   14,   12,    8,    3,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,

      134,  134,  134,  134,  134,  134,  134,  134,  134,  134
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[21] =
    {   0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 
    0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int ppParse_flex_flex_debug;
int ppParse_flex_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *ppParse_flextext;
#line 1 "ppParse_flex.l"
#line 2 "ppParse_flex.l"
// Copyright (C) 2013 Daniel J. Bates, Jonathan D. Hauenstein, Andrew J. Sommese, and Charles W. Wampler
#include "ppParse.h"
#include "ppParse_bison.h"

#define ppParse_flexlex ppParse_bisonlex

// preprocess array
preProcessArray *ppArray = NULL;

// processing line
char *ppLine = NULL;
int ppLineLen = 0;

// using a parameter homotopy
int ppUsingParamHomotopy = 0, ppAddAllNums = 0;

extern int *endOfFile;
extern int *lineNum;
/* %option nounput - do not warn about unput */
#line 597 "src/ppParse_flex.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int ppParse_flexlex_destroy (void );

int ppParse_flexget_debug (void );

void ppParse_flexset_debug (int debug_flag  );

YY_EXTRA_TYPE ppParse_flexget_extra (void );

void ppParse_flexset_extra (YY_EXTRA_TYPE user_defined  );

FILE *ppParse_flexget_in (void );

void ppParse_flexset_in  (FILE * in_str  );

FILE *ppParse_flexget_out (void );

void ppParse_flexset_out  (FILE * out_str  );

int ppParse_flexget_leng (void );

char *ppParse_flexget_text (void );

int ppParse_flexget_lineno (void );

void ppParse_flexset_lineno (int line_number  );

YYSTYPE * ppParse_flexget_lval (void );

void ppParse_flexset_lval (YYSTYPE * yylval_param  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int ppParse_flexwrap (void );
#else
extern int ppParse_flexwrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( ppParse_flextext, ppParse_flexleng, 1, ppParse_flexout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		unsigned n; \
		for ( n = 0; n < max_size && \
			     (c = getc( ppParse_flexin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( ppParse_flexin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, ppParse_flexin))==0 && ferror(ppParse_flexin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(ppParse_flexin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int ppParse_flexlex \
               (YYSTYPE * yylval_param );

#define YY_DECL int ppParse_flexlex \
               (YYSTYPE * yylval_param )
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after ppParse_flextext and ppParse_flexleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
        YYSTYPE * yylval;
    
#line 49 "ppParse_flex.l"


#line 788 "src/ppParse_flex.c"

    yylval = yylval_param;

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! ppParse_flexin )
			ppParse_flexin = stdin;

		if ( ! ppParse_flexout )
			ppParse_flexout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			ppParse_flexensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				ppParse_flex_create_buffer(ppParse_flexin,YY_BUF_SIZE );
		}

		ppParse_flex_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of ppParse_flextext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 135 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 171 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < ppParse_flexleng; ++yyl )
				if ( ppParse_flextext[yyl] == '\n' )
					   
    ppParse_flexlineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 51 "ppParse_flex.l"
{ // end of file
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
	     return ppEND;
           }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 55 "ppParse_flex.l"
{ // hom variable group
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
             return ppHOMVARGP;
           }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 59 "ppParse_flex.l"
{ // variable group
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
	     return ppVARGP;
           }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 63 "ppParse_flex.l"
{ // path variable
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
	     return ppPATHVAR;
           }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 67 "ppParse_flex.l"
{ // variable
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
      	     return ppVAR;
           }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 71 "ppParse_flex.l"
{ // parameter
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
	     return ppPARAM;
           }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 75 "ppParse_flex.l"
{ // const
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
	     return ppCONST;
           }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 79 "ppParse_flex.l"
{ // function
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
	     return ppFUNC;
           }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 83 "ppParse_flex.l"
{ // defined subfunction
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
             return ppSUBFUNC;
           } 
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 87 "ppParse_flex.l"
{ // number
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
	     ppParse_bisonlval.name = strdup(ppParse_flextext);
	     return ppNUMBER;
           }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 92 "ppParse_flex.l"
{ // sin, cos, tan, or exp
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
	     ppParse_bisonlval.name = strdup(ppParse_flextext);
	     return ppSCE;
	   }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 97 "ppParse_flex.l"
{ // pow 
             append_str(&ppLine, &ppLineLen, ppParse_flextext);
             ppParse_bisonlval.name = strdup(ppParse_flextext);
             return ppPOW;
           }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 102 "ppParse_flex.l"
{ // I
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
	     return ppI;
           }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 106 "ppParse_flex.l"
{ // Pi
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
	     return ppPi;
           }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 110 "ppParse_flex.l"
{ // name
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
		 ppParse_bisonlval.name = strdup(ppParse_flextext);
	     return ppNAME;
           }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 115 "ppParse_flex.l"
{ // end of line
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
	     return ppEOL;
           }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 119 "ppParse_flex.l"
{ // -+*/^(),=
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
	     return ppParse_flextext[0];
           }
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 123 "ppParse_flex.l"
; // ignore it
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 124 "ppParse_flex.l"
{ // other symbol - error!
	     append_str(&ppLine, &ppLineLen, ppParse_flextext);
	     ppParse_bisonerror("invalid character");
           }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 129 "ppParse_flex.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1042 "src/ppParse_flex.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed ppParse_flexin at a new source and called
			 * ppParse_flexlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = ppParse_flexin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( ppParse_flexwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * ppParse_flextext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of ppParse_flexlex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					ppParse_flexrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			ppParse_flexrestart(ppParse_flexin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) ppParse_flexrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 135 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 135 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 134);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					ppParse_flexrestart(ppParse_flexin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( ppParse_flexwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve ppParse_flextext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		   
    ppParse_flexlineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void ppParse_flexrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        ppParse_flexensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            ppParse_flex_create_buffer(ppParse_flexin,YY_BUF_SIZE );
	}

	ppParse_flex_init_buffer(YY_CURRENT_BUFFER,input_file );
	ppParse_flex_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void ppParse_flex_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		ppParse_flexpop_buffer_state();
	 *		ppParse_flexpush_buffer_state(new_buffer);
     */
	ppParse_flexensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	ppParse_flex_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (ppParse_flexwrap()) processing, but the only time this flag
	 * is looked at is after ppParse_flexwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void ppParse_flex_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	ppParse_flexin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE ppParse_flex_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) ppParse_flexalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in ppParse_flex_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) ppParse_flexalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in ppParse_flex_create_buffer()" );

	b->yy_is_our_buffer = 1;

	ppParse_flex_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with ppParse_flex_create_buffer()
 * 
 */
    void ppParse_flex_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		ppParse_flexfree((void *) b->yy_ch_buf  );

	ppParse_flexfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a ppParse_flexrestart() or at EOF.
 */
    static void ppParse_flex_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	ppParse_flex_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then ppParse_flex_init_buffer was _probably_
     * called from ppParse_flexrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void ppParse_flex_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		ppParse_flex_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void ppParse_flexpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	ppParse_flexensure_buffer_stack();

	/* This block is copied from ppParse_flex_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from ppParse_flex_switch_to_buffer. */
	ppParse_flex_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void ppParse_flexpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	ppParse_flex_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		ppParse_flex_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void ppParse_flexensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)ppParse_flexalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in ppParse_flexensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)ppParse_flexrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in ppParse_flexensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE ppParse_flex_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) ppParse_flexalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in ppParse_flex_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	ppParse_flex_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to ppParse_flexlex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       ppParse_flex_scan_bytes() instead.
 */
YY_BUFFER_STATE ppParse_flex_scan_string (yyconst char * yystr )
{
    
	return ppParse_flex_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to ppParse_flexlex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE ppParse_flex_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) ppParse_flexalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in ppParse_flex_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = ppParse_flex_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in ppParse_flex_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up ppParse_flextext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		ppParse_flextext[ppParse_flexleng] = (yy_hold_char); \
		(yy_c_buf_p) = ppParse_flextext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		ppParse_flexleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int ppParse_flexget_lineno  (void)
{
        
    return ppParse_flexlineno;
}

/** Get the input stream.
 * 
 */
FILE *ppParse_flexget_in  (void)
{
        return ppParse_flexin;
}

/** Get the output stream.
 * 
 */
FILE *ppParse_flexget_out  (void)
{
        return ppParse_flexout;
}

/** Get the length of the current token.
 * 
 */
int ppParse_flexget_leng  (void)
{
        return ppParse_flexleng;
}

/** Get the current token.
 * 
 */

char *ppParse_flexget_text  (void)
{
        return ppParse_flextext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void ppParse_flexset_lineno (int  line_number )
{
    
    ppParse_flexlineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see ppParse_flex_switch_to_buffer
 */
void ppParse_flexset_in (FILE *  in_str )
{
        ppParse_flexin = in_str ;
}

void ppParse_flexset_out (FILE *  out_str )
{
        ppParse_flexout = out_str ;
}

int ppParse_flexget_debug  (void)
{
        return ppParse_flex_flex_debug;
}

void ppParse_flexset_debug (int  bdebug )
{
        ppParse_flex_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from ppParse_flexlex_destroy(), so don't allocate here.
     */

    /* We do not touch ppParse_flexlineno unless the option is enabled. */
    ppParse_flexlineno =  1;
    
    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    ppParse_flexin = stdin;
    ppParse_flexout = stdout;
#else
    ppParse_flexin = (FILE *) 0;
    ppParse_flexout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * ppParse_flexlex_init()
     */
    return 0;
}

/* ppParse_flexlex_destroy is for both reentrant and non-reentrant scanners. */
int ppParse_flexlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		ppParse_flex_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		ppParse_flexpop_buffer_state();
	}

	/* Destroy the stack itself. */
	ppParse_flexfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * ppParse_flexlex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *ppParse_flexalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *ppParse_flexrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void ppParse_flexfree (void * ptr )
{
	free( (char *) ptr );	/* see ppParse_flexrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 129 "ppParse_flex.l"



void append_str(char **str1, int *lenStr1, char *str2)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: append str2 onto str1 and update its length            *
\***************************************************************/
{
  *lenStr1 += strlen(str2);
  *str1 = (char *)brealloc(*str1, (*lenStr1 + 1) * sizeof(char));
  strcat(*str1, str2);

  return;
}

int lookup_preProcessArray_type(int *loc, preProcessArrayType *Array, char *name)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES: 1 - found, 0 - not found                       *
* NOTES: lookup an entry in ppType                              *
\***************************************************************/
{
  int j, rV = 0, len = strlen(name);

  *loc = -1; 

  for (j = 0; j < Array->numType && !rV; j++)
    if (len == Array->nameSize[j] && !strcmp(name, Array->name[j]))
    { // found a match!
      rV = 1;
      *loc = j;
    }

  return rV;
}

int lookup_preProcessArray(int *type, int *loc, preProcessArray *Array, char *name)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES: 1 - found, 0 - not found                       *
* NOTES: lookup an entry in Array                               *
\***************************************************************/
{
  int i, rV = 0, numTypes = Array->numTypes;

  *type = *loc = -1;

  for (i = 0; i < numTypes && !rV; i++)
  {
    rV = lookup_preProcessArray_type(loc, &Array->types[i], name);
    if (rV)
    { // found a match!
      *type = i;
    }
  }

  return rV;
}

void negate_lastEntry(preProcessArrayType *Numbers)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: negate the last entry in Numbers                       *
\***************************************************************/
{
  int loc = Numbers->numType - 1;
  char *oldName = Numbers->name[loc];

  Numbers->nameSize[loc]++;
  Numbers->name[loc] = (char *)bmalloc((Numbers->nameSize[loc] + 1) * sizeof(char));
  sprintf(Numbers->name[loc], "-%s", oldName);

  free(oldName);

  return;
}

void addEntry_preProcessArray_type(preProcessArrayType *Array, char *name, int isDefined, int lineNo)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: add an entry to Array                                  *
\***************************************************************/
{
  int loc = Array->numType;

  // add the entry
  Array->numType++;

  if (Array->numType > Array->allocSize)
  { // increase the allocated size
    if (Array->allocSize == 0)
      Array->allocSize = 1;
    else
      Array->allocSize *= 2;

    Array->isDefined = (int *)brealloc(Array->isDefined, Array->allocSize * sizeof(int));
    Array->lineNumber = (int *)brealloc(Array->lineNumber, Array->allocSize * sizeof(int));
    Array->nameSize = (int *)brealloc(Array->nameSize, Array->allocSize * sizeof(int));
    Array->name = (char **)brealloc(Array->name, Array->allocSize * sizeof(char *));
  }

  Array->isDefined[loc] = isDefined;
  Array->lineNumber[loc] = lineNo;
  Array->nameSize[loc] = strlen(name);
  Array->name[loc] = (char *)bmalloc((Array->nameSize[loc] + 1) * sizeof(char));
  strcpy(Array->name[loc], name);

  return;
}

void initialize_preProcessArray_type(preProcessArrayType *Array)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: initializes Array                                      *
\***************************************************************/
{
  Array->numType = 0;
  Array->allocSize = 0;
  Array->isDefined = NULL;
  Array->lineNumber = NULL;
  Array->nameSize = NULL;
  Array->name = NULL;

  return;
}

void initialize_preProcessArray(preProcessArray *Array)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: initializes Array                                      *
\***************************************************************/
{
  int i;

  Array->numTypes = 10;
  Array->types = (preProcessArrayType *)bmalloc(Array->numTypes * sizeof(preProcessArrayType));
  for (i = 0; i < Array->numTypes; i++)
    initialize_preProcessArray_type(&Array->types[i]);

  // setup 'I', 'Pi', '0' & '1'
  addEntry_preProcessArray_type(&Array->types[CONSTANTTYPE], "I", 1, 0);
  addEntry_preProcessArray_type(&Array->types[CONSTANTTYPE], "Pi", 1, 0);
  addEntry_preProcessArray_type(&Array->types[NUMBERTYPE], "0", 1, 0);
  addEntry_preProcessArray_type(&Array->types[NUMBERTYPE], "1", 1, 0);
 
  return;
}

void copy_preProcessArray_type(preProcessArrayType *Out, preProcessArrayType *In)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: copy In to Out                                         *
\***************************************************************/
{
  int i;

  Out->numType = In->numType;

  if (In->numType > 0)
  { // setup the structures
    Out->allocSize = Out->numType;
    Out->isDefined = (int *)bmalloc(Out->numType * sizeof(int));
    Out->lineNumber = (int *)bmalloc(Out->numType * sizeof(int));
    Out->nameSize = (int *)bmalloc(Out->numType * sizeof(int));
    Out->name = (char **)bmalloc(Out->numType * sizeof(char *));

    for (i = 0; i < In->numType; i++)
    {
      Out->isDefined[i] = In->isDefined[i];
      Out->lineNumber[i] = In->lineNumber[i];
      Out->nameSize[i] = In->nameSize[i];
      Out->name[i] = (char *)bmalloc((Out->nameSize[i] + 1) * sizeof(char));
      strcpy(Out->name[i], In->name[i]);
    }
  }
  else
  { // NULL out the pointers
    Out->allocSize = 0;
    Out->isDefined = NULL;
    Out->lineNumber = NULL;
    Out->nameSize = NULL;
    Out->name = NULL;
  }

  return;
}

void copy_preProcessArray(preProcessArray *Out, preProcessArray *In)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: copy In to Out                                         *
\***************************************************************/
{
  int i;

  Out->numTypes = In->numTypes;

  if (In->numTypes > 0)
  { // copyt data
    Out->types = (preProcessArrayType *)bmalloc(Out->numTypes * sizeof(preProcessArrayType));
    for (i = 0; i < In->numTypes; i++)
      copy_preProcessArray_type(&Out->types[i], &In->types[i]);
  }
  else
  { // NULL out pointer 
    Out->types = NULL;
  }

  return;
}

void clear_preProcessArray_type(preProcessArrayType *Array)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: clears Array                                           *
\***************************************************************/
{
  int i;

  if (Array->numType > 0)
  {
    for (i = 0; i < Array->numType; i++)
      free(Array->name[i]);
    free(Array->isDefined);
    free(Array->lineNumber);
    free(Array->nameSize);
    free(Array->name);
  }
  
  return;
}

void clear_preProcessArray(preProcessArray *Array)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: clears Array                                           *
\***************************************************************/
{
  int i;

  if (Array->numTypes > 0)
  {
    for (i = 0; i < Array->numTypes; i++)
      clear_preProcessArray_type(&Array->types[i]);
  
    free(Array->types);
    Array->numTypes = 0;
    Array->types = NULL;
  }

  return;
}

void verify_preProcessArray_type(preProcessArrayType *Array)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: verify that everything is defined in Array             *
\***************************************************************/
{
  int i;

  for (i = 0; i < Array->numType; i++)
    if (!Array->isDefined[i])
    { // not defined
      printf("ERROR: After parsing, it appears that the symbol '%s' is not defined!\n", Array->name[i]);
      bexit(ERROR_INPUT_SYNTAX);
    }
 
  return;
}

void verify_existence_definedSubfunction(preProcessArrayType *Array)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: verify that everything is defined in Array has a file  *
\***************************************************************/
{
  int i, size = 0;
  char *name = NULL;
  FILE *IN = NULL;

  for (i = 0; i < Array->numType; i++)
  {
    size = 1 + snprintf(NULL, 0, "%s.func", Array->name[i]);
    name = (char *)brealloc(name, size * sizeof(char));
    sprintf(name, "%s.func", Array->name[i]);
    IN = fopen(name, "r");
    if (IN == NULL)
    { // file does not exist
      printf("ERROR: The file '%s' for the defined subfunction '%s' does not exist!\n", name, Array->name[i]);
      bexit(ERROR_INPUT_SYNTAX);
    }
  }

  if (name != NULL)
    free(name);

  return;
}

void verify_preProcessArray(preProcessArray *Array)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: verify that everything is defined in Array             *
\***************************************************************/
{
  int i;

  // verify the data
  for (i = 0; i < Array->numTypes; i++)
    verify_preProcessArray_type(&Array->types[i]);

  // verify that we have defined subfunction files
  verify_existence_definedSubfunction(&Array->types[DEFINEDSUBFUNCTIONTYPE]);

  // verify that there are at most 1 path variables
  if (Array->types[PATHVARIABLETYPE].numType > 1)
  { // error - too many
    printf("ERROR: After parsing, it appears that there are %d path variables defined (there must be at most 1)!\n", Array->types[PATHVARIABLETYPE].numType);
    bexit(ERROR_INPUT_SYNTAX);
  }

  return;
}

void verify_standard_homotopy(preProcessArray *Array, variablegroupArray *vargpArray, int onlyOneGp)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: verify settings for a standard homotopy                *
\***************************************************************/
{
  // check path variables
  if (Array->types[PATHVARIABLETYPE].numType != 0)
  { // error - too many
    printf("ERROR: After parsing, it appears that at least one path variable has been defined!\n");
    bexit(ERROR_INPUT_SYNTAX);
  }

  // check parameters
  if (Array->types[PARAMETERTYPE].numType != 0)
  { // error - too many
    printf("ERROR: After parsing, it appears that at least one parameter has been defined!\n");
    bexit(ERROR_INPUT_SYNTAX);
  }

  // check variable
  if (Array->types[VARIABLETYPE].numType != 0)
  { // error - too many
    printf("ERROR: After parsing, it appears that at least one 'variable' has been used!\n");
    bexit(ERROR_INPUT_SYNTAX);
  }

  // check variable groups
  if (onlyOneGp)
  { // check that there is only 1 variable group
    if (vargpArray->numGps > 1)
    { // error - too many
      printf("ERROR: Your settings only allow for one variable group to be used (you have requested to use %d variable groups)!\n", vargpArray->numGps);
      bexit(ERROR_INPUT_SYNTAX);
    }
  }

  return;
}

void verify_parameter_homotopy(preProcessArray *Array)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: verify settings for a standard homotopy                *
\***************************************************************/
{
  // check path variables
  if (Array->types[PATHVARIABLETYPE].numType != 0)
  { // error - too many
    printf("ERROR: After parsing, it appears that at least one path variable has been defined!\n");
    bexit(ERROR_INPUT_SYNTAX);
  }

  // check parameters
  if (Array->types[PARAMETERTYPE].numType < 1)
  { // error - too many
    printf("ERROR: After parsing, it appears that there are %d parameters defined (there must be at least 1)!\n", Array->types[PARAMETERTYPE].numType);
    bexit(ERROR_INPUT_SYNTAX);
  }

  // check variable
  if (Array->types[VARIABLETYPE].numType != 0)
  { // error - too many
    printf("ERROR: After parsing, it appears that at least one 'variable' has been used!\n");
    bexit(ERROR_INPUT_SYNTAX);
  }

  return;
}

void verify_userdefined_homotopy(preProcessArray *Array, int userHom)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: verify settings for a standard homotopy                *
\***************************************************************/
{
  // check path variables
  if (Array->types[PATHVARIABLETYPE].numType != 1)
  { // error - too many
    printf("ERROR: After parsing, it appears that there are %d path variables defined (there must be exactly 1)!\n", Array->types[PATHVARIABLETYPE].numType);
    bexit(ERROR_INPUT_SYNTAX);
  }

  // check parameters
  if (Array->types[PARAMETERTYPE].numType < 1)
  { // error - too many
    printf("ERROR: After parsing, it appears that there are %d parameters defined (there must be at least 1)!\n", Array->types[PARAMETERTYPE].numType);
    bexit(ERROR_INPUT_SYNTAX);
  }

  if (userHom == 2)
  { // check variable
    if (Array->types[VARIABLETYPE].numType != 0)
    { // error - too many
      printf("ERROR: After parsing, it appears that at least one 'variable' has been used!\n");
      printf("With this setting, you should use either 'variable_group' or 'hom_variable_group'.\n");
      bexit(ERROR_INPUT_SYNTAX);
    }
  }
  else
  { // check variable_group
    if (Array->types[VARIABLEGROUPTYPE].numType != 0)
    { // error - too many
      printf("ERROR: After parsing, it appears that at least one 'variable_group' has been used!\n");
      printf("Standard user defined homotopies should use 'variable' rather than 'variable_group'.\n");
      bexit(ERROR_INPUT_SYNTAX);
    }

    // check hom variable_group
    if (Array->types[HOMVARIABLEGROUPTYPE].numType != 0)
    { // error - too many
      printf("ERROR: After parsing, it appears that at least one 'hom_variable_group' has been used!\n");
      printf("Standard user defined homotopies should use 'variable' rather than 'hom_variable_group'.\n");
      bexit(ERROR_INPUT_SYNTAX);
    }
  }

  return;
}

int preProcessParse(preProcessArray *preProcArray, FILE *fp, int paramHom, int addAllNums)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: preprocess the file                                    *
\***************************************************************/
{
  int rV = 0, endFile = 0;

  // initialize
  ppLine = NULL;
  endOfFile = &endFile;

  // setup ppArray
  ppArray = preProcArray;
  initialize_preProcessArray(ppArray);

  // setup line number
  lineNum = &ppParse_flexlineno;
  *lineNum = 1;

  // setup ppUsingParamHomotopy
  ppUsingParamHomotopy = (paramHom == 1 || paramHom == 2);

  // setup ppAddAllNums
  ppAddAllNums = addAllNums;

  // parse the file
  ppParse_flexin = fp;
  do
  { // clear out the line
    ppLineLen = 1;
    ppLine = (char *)brealloc(ppLine, ppLineLen * sizeof(char));
    ppLine[0] = '\0';

    // parse the line
    rV = ppParse_bisonparse(); 

    // increment line number
    (*lineNum)++;

  } while (!rV && !endFile);

  // verify that everything that needs defined has been defined
  verify_preProcessArray(ppArray);

  // clear memory
  ppParse_flexin = NULL;
  ppArray = NULL;

  free(ppLine);
  ppLineLen = 0;

  return rV;
}

int ppParse_flexwrap()
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: called when parser reaches EOF                         *
\***************************************************************/
{ // parser is complete
  return 1;
}

int ppParse_bisonerror(char *s)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: called when preprocessor reaches an error              *
\***************************************************************/
{ // error in parser
  if (!strcmp(s,"invalid character"))
    printf("ERROR: The '%s' is an %s in system statement %d.\n", ppParse_flextext, s, ppParse_flexlineno);
  else
    printf("ERROR: There was an error (%s) near '%s' in system statement %d.\n", s, ppParse_flextext, ppParse_flexlineno);
  errorStatement();

  return 0;
}

void errorStatement()
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: called when parser reaches an error-should never occur *
\***************************************************************/
{
  printf("Statement %d up to error: '%s'\n", ppParse_flexlineno, ppLine);
  bexit(ERROR_INPUT_SYNTAX);

  return;
}

void print_preproc_data(FILE *OUT, int numFuncs, int numVarGps, int numHomGps, int *types, int *sizes)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: prints the required data to OUT                        *
\***************************************************************/
{
  int i, numGps = numVarGps + numHomGps;

  // print the number of functions, number of homogeneous variable groups, and number of variable groups
  fprintf(OUT, "%d %d %d\n", numFuncs, numHomGps, numVarGps);
  // print the type & size of each of the groups
  for (i = 0; i < numGps; i++)
    fprintf(OUT, "%d %d\n", types[i], sizes[i]);

  return;
}

void setup_variablegroup_numbers(preProcessArray *Array, int *numHomGps, int **sizeHomGps, int *numVarGps, int **sizeVarGps)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: setup the variable group numbers                       *
\***************************************************************/
{
  int i, j, found, lineNum, lineCount = 0, *lines = NULL, *types = NULL, currVar = 0, currHom = 0;
  int numVar = Array->types[VARIABLEGROUPTYPE].numType, numHomVar = Array->types[HOMVARIABLEGROUPTYPE].numType;

  // initialize counts
  *numHomGps = *numVarGps = 0;

  // count the number of line numbers used in var & hom_var
  for (i = 0; i < numVar; i++)
  { // see if used
    found = 0;
    lineNum = Array->types[VARIABLEGROUPTYPE].lineNumber[i];
    for (j = 0; j < lineCount && !found; j++)
      if (lines[j] == lineNum)
        found = 1;

    if (!found)
    { // add to lines & types
      lines = (int *)brealloc(lines, (lineCount + 1) * sizeof(int));
      types = (int *)brealloc(types, (lineCount + 1) * sizeof(int));
      lines[lineCount] = lineNum;
      types[lineCount] = 1; // variable group
      lineCount++;

      // increment the count of variable groups
      (*numVarGps)++;
    }
  }
  for (i = 0; i < numHomVar; i++)
  { // see if used
    found = 0;
    lineNum = Array->types[HOMVARIABLEGROUPTYPE].lineNumber[i];
    for (j = 0; j < lineCount && !found; j++)
      if (lines[j] == lineNum)
        found = 1;

    if (!found)
    { // add to lines
      lines = (int *)brealloc(lines, (lineCount + 1) * sizeof(int));
      types = (int *)brealloc(types, (lineCount + 1) * sizeof(int));
      lines[lineCount] = lineNum;
      types[lineCount] = 0; // hom variable group
      lineCount++;

      // increment the count of hom variable groups
      (*numHomGps)++;
    }
  }

  // allocate sizeHomGps & sizeVarGps
  *sizeVarGps = (int *)bmalloc(*numVarGps * sizeof(int));
  *sizeHomGps = (int *)bmalloc(*numHomGps * sizeof(int));

  // setup the group numbers
  for (i = 0; i < lineCount; i++)
  { // find the minimum still left
    lineNum = INT_MAX; 
    found = 0;
    for (j = 0; j < lineCount; j++)
      if (lines[j] < lineNum && lines[j] >= 0)
      { // store this line number
        lineNum = lines[j];
        found = j;
      }

    // determine the type and setup the line numbers and count
    if (types[found])
    { // variable group
      (*sizeVarGps)[currVar] = 0;
      for (j = 0; j < numVar; j++)
        if (Array->types[VARIABLEGROUPTYPE].lineNumber[j] == lineNum)
        {
          Array->types[VARIABLEGROUPTYPE].lineNumber[j] = i;
          (*sizeVarGps)[currVar]++;
        }

      currVar++;
    }
    else
    { // hom variable group
      (*sizeHomGps)[currHom] = 0;
      for (j = 0; j < numHomVar; j++)
        if (Array->types[HOMVARIABLEGROUPTYPE].lineNumber[j] == lineNum)
        {
          Array->types[HOMVARIABLEGROUPTYPE].lineNumber[j] = i;
          (*sizeHomGps)[currHom]++;
        }

      currHom++;
    }

    // kill off this line number
    lines[found] = -1;
  }

  // clear memory
  free(types);
  free(lines);

  return;
}

void initialize_variablegroupArray(variablegroupArray *vargpArray)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: initialize vargpArray                                  *
\***************************************************************/
{
  vargpArray->numGps = vargpArray->numHomGps = vargpArray->numVarGps = vargpArray->totalNumVars = 0;
  vargpArray->types = vargpArray->sizes = vargpArray->varLoc = vargpArray->homLoc = vargpArray->groupNumber = vargpArray->nameSize = NULL;
  vargpArray->name = NULL;

  return;
}

void clear_variablegroupArray(variablegroupArray *vargpArray)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: clear vargpArray                                       *
\***************************************************************/
{
  int i;

  // clear name
  for (i = 0; i < vargpArray->totalNumVars; i++)
    free(vargpArray->name[i]);
  free(vargpArray->name);

  // clear other data
  free(vargpArray->types);
  free(vargpArray->sizes);
  free(vargpArray->varLoc);
  free(vargpArray->homLoc);
  free(vargpArray->groupNumber);
  free(vargpArray->nameSize);

  // NULL out data
  vargpArray->numGps = vargpArray->numHomGps = vargpArray->numVarGps = vargpArray->totalNumVars = 0;
  vargpArray->types = vargpArray->sizes = vargpArray->varLoc = vargpArray->homLoc = vargpArray->groupNumber = vargpArray->nameSize = NULL;
  vargpArray->name = NULL;

  return;
}

void setup_variablegroupArray(preProcessArray *Array, variablegroupArray *vargpArray, int userHom)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: setup vargpArray using Array                           *
\***************************************************************/
{
  int i, j, found, lineNum, lineCount = 0, *lines = NULL, *types = NULL, currVar = 0, currVarGp = 0;
  int numVar = Array->types[VARIABLEGROUPTYPE].numType, numHomVar = Array->types[HOMVARIABLEGROUPTYPE].numType;

  // initialize vargpArray
  initialize_variablegroupArray(vargpArray);

  if (userHom)
  { // just using 'variable' data
    vargpArray->totalNumVars = Array->types[VARIABLETYPE].numType;
    vargpArray->numGps = vargpArray->numHomGps = vargpArray->numVarGps = 0;
    vargpArray->types = vargpArray->sizes = vargpArray->varLoc = vargpArray->homLoc = vargpArray->groupNumber = vargpArray->nameSize = NULL;
    // setup name
    vargpArray->name = (char **)bmalloc(vargpArray->totalNumVars * sizeof(char *));
    for (i = 0; i < vargpArray->totalNumVars; i++)
    {
      vargpArray->name[i] = (char *)bmalloc((Array->types[VARIABLETYPE].nameSize[i] + 1) * sizeof(char));
      strcpy(vargpArray->name[i], Array->types[VARIABLETYPE].name[i]);
    }
  }
  else
  { // using both 'variable_group' & 'hom_variable_group'

    // count the number of line numbers used in var & hom_var
    for (i = 0; i < numVar; i++)
    { // see if used
      found = 0;
      lineNum = Array->types[VARIABLEGROUPTYPE].lineNumber[i];
      for (j = 0; j < lineCount && !found; j++)
        if (lines[j] == lineNum)
          found = 1;

      if (!found)
      { // add to lines & types
        lines = (int *)brealloc(lines, (lineCount + 1) * sizeof(int));
        types = (int *)brealloc(types, (lineCount + 1) * sizeof(int));
        lines[lineCount] = lineNum;
        types[lineCount] = 1; // variable group
        lineCount++;
  
        // increment the count of variable groups
        vargpArray->numVarGps++;
      }
    }
    for (i = 0; i < numHomVar; i++)
    { // see if used
      found = 0;
      lineNum = Array->types[HOMVARIABLEGROUPTYPE].lineNumber[i];
      for (j = 0; j < lineCount && !found; j++)
        if (lines[j] == lineNum)
          found = 1;
 
      if (!found)
      { // add to lines
        lines = (int *)brealloc(lines, (lineCount + 1) * sizeof(int));
        types = (int *)brealloc(types, (lineCount + 1) * sizeof(int));
        lines[lineCount] = lineNum;
        types[lineCount] = 0; // hom variable group
        lineCount++;

        // increment the count of hom variable groups
        vargpArray->numHomGps++;
      }
    }

    // setup the total number of variable groups
    vargpArray->numGps = vargpArray->numVarGps + vargpArray->numHomGps;
 
    // allocate types & sizes
    vargpArray->types = (int *)bmalloc(vargpArray->numGps * sizeof(int)); 
    vargpArray->sizes = (int *)bmalloc(vargpArray->numGps * sizeof(int)); 
  
    // allocate varLoc & homLoc
    vargpArray->varLoc = (int *)bmalloc(numVar * sizeof(int));
    vargpArray->homLoc = (int *)bmalloc(numHomVar * sizeof(int));

    // count the total number of variables
    vargpArray->totalNumVars = vargpArray->numVarGps + numVar + numHomVar;
 
    // allocate groupNumber, nameSize, name
    vargpArray->groupNumber = (int *)bmalloc(vargpArray->totalNumVars * sizeof(int));
    vargpArray->nameSize = (int *)bmalloc(vargpArray->totalNumVars * sizeof(int));
    vargpArray->name = (char **)bmalloc(vargpArray->totalNumVars * sizeof(char *));

    // setup the new homogenizing variables
    for (i = 0; i < vargpArray->numVarGps; i++)
    { // setup nameSize[i] & name[i]
      vargpArray->nameSize[i] = snprintf(NULL, 0, "HOM_VAR_%d", i);
      vargpArray->name[i] = (char *)bmalloc((1 + vargpArray->nameSize[i]) * sizeof(char));
      sprintf(vargpArray->name[i], "HOM_VAR_%d", i);  
    }
    // move past these variables
    currVar = vargpArray->numVarGps;
 
    // setup the group numbers
    for (i = 0; i < lineCount; i++)
    { // find the minimum still left
      lineNum = INT_MAX;
      found = 0;
      for (j = 0; j < lineCount; j++)
        if (lines[j] < lineNum && lines[j] >= 0)
        { // store this line number
          lineNum = lines[j];
          found = j;
        }

      // setup type
      vargpArray->types[i] = types[found];
      // initialize size
      vargpArray->sizes[i] = 0;

      // setup the rest of the data
      if (types[found])
      { // variable group
        vargpArray->groupNumber[currVarGp] = i; // setup variable group for new homogenizing variable
        currVarGp++;

        for (j = 0; j < numVar; j++)
          if (Array->types[VARIABLEGROUPTYPE].lineNumber[j] == lineNum)
          { // setup the information about this variable
            vargpArray->varLoc[j] = currVar; // setup location
            vargpArray->groupNumber[currVar] = i; // variable group number
            // setup nameSize & name
            vargpArray->nameSize[currVar] = Array->types[VARIABLEGROUPTYPE].nameSize[j];
            vargpArray->name[currVar] = (char *)bmalloc((1 + vargpArray->nameSize[currVar]) * sizeof(char));
            strcpy(vargpArray->name[currVar], Array->types[VARIABLEGROUPTYPE].name[j]);
            // increment the current variable
            currVar++;
            // increment the size of this variable group
            vargpArray->sizes[i]++;
          }
      }
      else
      { // hom variable group
        for (j = 0; j < numHomVar; j++)
          if (Array->types[HOMVARIABLEGROUPTYPE].lineNumber[j] == lineNum)
          { // setup the information about this variable
            vargpArray->homLoc[j] = currVar; // setup location
            vargpArray->groupNumber[currVar] = i; // variable group number
            // setup nameSize & name
            vargpArray->nameSize[currVar] = Array->types[HOMVARIABLEGROUPTYPE].nameSize[j];
            vargpArray->name[currVar] = (char *)bmalloc((1 + vargpArray->nameSize[currVar]) * sizeof(char));
            strcpy(vargpArray->name[currVar], Array->types[HOMVARIABLEGROUPTYPE].name[j]);
            // increment the current variable
            currVar++;
            // increment the size of this variable group
            vargpArray->sizes[i]++;
          }
      }

      // kill off this line number
      lines[found] = -1;
    }
  
    // clear memory
    free(types);
    free(lines);
  }

  return;
} 



